@@ -41,7 +41,7 @@ public:
     explicit EditDisplayAlarmDlg(bool Template, QWidget* parent = nullptr, GetResourceType = RES_PROMPT);
     EditDisplayAlarmDlg(bool Template, const KAEvent&, bool newAlarm, QWidget* parent = nullptr,
                  GetResourceType = RES_PROMPT, bool readOnly = false);
-    ~EditDisplayAlarmDlg();
+    ~EditDisplayAlarmDlg() override;
 
     // Methods to initialise values in the New Alarm dialogue.
     // N.B. setTime() must be called first to set the date-only characteristic,
@@ -192,7 +192,7 @@ public:
     explicit EditEmailAlarmDlg(bool Template, QWidget* parent = nullptr, GetResourceType = RES_PROMPT);
     EditEmailAlarmDlg(bool Template, const KAEvent&, bool newAlarm, QWidget* parent = nullptr,
                       GetResourceType = RES_PROMPT, bool readOnly = false);
-    ~EditEmailAlarmDlg();
+    ~EditEmailAlarmDlg() override;
 
     // Methods to initialise values in the New Alarm dialogue.
     // N.B. setTime() must be called first to set the date-only characteristic,
