@@ -10,17 +10,16 @@
 
 #include "lib/combobox.h"
 
-#include <KIdentityManagement/IdentityCombo>
+#include <KIdentityManagementWidgets/IdentityCombo>
 
 class QMouseEvent;
 class QKeyEvent;
 
-
-class EmailIdCombo : public KIdentityManagement::IdentityCombo
+class EmailIdCombo : public KIdentityManagementWidgets::IdentityCombo
 {
     Q_OBJECT
 public:
-    explicit EmailIdCombo(KIdentityManagement::IdentityManager*, QWidget* parent = nullptr);
+    explicit EmailIdCombo(KIdentityManagementCore::IdentityManager*, QWidget* parent = nullptr);
     void setReadOnly(bool ro)    { mReadOnly = ro; }
 
 protected:
