@@ -114,7 +114,7 @@ void MinuteTimer::slotTimer()
 =  Application-wide timer synchronized to midnight.
 =============================================================================*/
 
-QVector<DailyTimer*> DailyTimer::mFixedTimers;
+QList<DailyTimer*> DailyTimer::mFixedTimers;
 
 DailyTimer::DailyTimer(const QTime& timeOfDay, bool fixed)
     : mTime(timeOfDay)
@@ -234,4 +234,6 @@ void DailyTimer::slotTimer()
     qCDebug(KALARM_LOG) << "DailyTimer::slotTimer: at" << mTime.hour() << ":" << mTime.minute() << ": interval =" << interval/3600 << ":" << (interval/60)%60 << ":" << interval%60;
 }
 
+#include "moc_synchtimer.cpp"
+
 // vim: et sw=4:
