@@ -26,6 +26,7 @@
 #include <QHBoxLayout>
 #include <QStandardPaths>
 #include <QMimeDatabase>
+using namespace Qt::Literals::StringLiterals;
 
 //clazy:excludeall=non-pod-global-static
 
@@ -135,7 +136,7 @@ void SoundPicker::showSpeak(bool show)
     if (show != mSpeakShowing)
     {
         // Note that 'Speak' is always the last option.
-        if (show)
+        if (show)                                  //cppcheck-suppress[knownConditionTrueFalse]  may be true if text to speech support
             mTypeCombo->addItem(i18n_combo_Speak(), Preferences::Sound_Speak);
         else
         {
@@ -260,15 +261,15 @@ void SoundPicker::slotPickFile()
         return;
     if (accepted)
     {
-        float volume, fadeVolume;
+        float vol, fadeVol;
         int   fadeTime;
-        dlg->getVolume(volume, fadeVolume, fadeTime);
-        QUrl file    = dlg->getFile();
-        if (!file.isEmpty())
-            mFile    = file;
+        dlg->getVolume(vol, fadeVol, fadeTime);
+        QUrl file_   = dlg->getFile();
+        if (!file_.isEmpty())
+            mFile    = file_;
         mRepeatPause = dlg->repeatPause();
-        mVolume      = volume;
-        mFadeVolume  = fadeVolume;
+        mVolume      = vol;
+        mFadeVolume  = fadeVol;
         mFadeSeconds = fadeTime;
     }
     if (mFile.isEmpty())
@@ -318,10 +319,10 @@ bool SoundPicker::browseFile(QString& file, QString& defaultDir, const QString&
         for (const QMimeType& mimeType : allMimeTypes)
             if (mimeType.name().startsWith(QStringLiteral("audio/")))
             {
-                audioFilter += mimeType.globPatterns().join(QLatin1Char(' '));
-                audioFilter += QLatin1Char(' ');
+                audioFilter += mimeType.globPatterns().join(' '_L1);
+                audioFilter += ' '_L1;
             }
-        audioFilter[audioFilter.length() - 1] = QLatin1Char(')');
+        audioFilter[audioFilter.length() - 1] = ')'_L1;
     }
 
     static QString kdeSoundDir;     // directory containing KDE sound files
